pub struct NdArray<T> {
pub dims: Vec<usize>,
pub data: Vec<T>,
}postgres_backend only.Expand description
Postgres allows multi-dimensional arrays of at most 6 dimensions. Internally they are stored as a flattened
representation with the dimension information encoded in the header. This struct represents a
multi-dimensional array with elements of type T as opposed to Vec
Fields
dims: Vec<usize>A list that describes how many values for each dimension are returned
data: Vec<T>The actual data flattened to a single array
This array contains values ordered by the left most dimension which means there will be dim[0] values for the first element of the second dimension followed by dim[0] values for the second element of the second dimensions and so up to dim[1] times. Afterwards that number of values is repeated for dim[2], and so for all dimensions in the dimension field above